@@ -377,7 +377,7 @@ class LoggingWrapper(StringIO):
         pass
 
 
-def get_browser(product, binary, prefs_root):
+def get_browser(product, binary, prefs_root, **kwargs):
     browser_classes = {"firefox": browser.FirefoxBrowser,
                        "servo": browser.ServoBrowser,
                        "b2g": browser.B2GBrowser}
@@ -388,6 +388,9 @@ def get_browser(product, binary, prefs_root):
     if product in ("firefox", "b2g"):
         browser_kwargs["prefs_root"] = prefs_root
 
+    if product == "b2g":
+        browser_kwargs["no_backup"] = kwargs.get("b2g_no_backup", False)
+
     return browser_cls, browser_kwargs
 
 def get_options(product):
@@ -441,7 +444,7 @@ def run_tests(tests_root, metadata_root, prefs_root, test_types, binary=None,
 
         logger.info("Using %i client processes" % processes)
 
-        browser_cls, browser_kwargs = get_browser(product, binary, prefs_root)
+        browser_cls, browser_kwargs = get_browser(product, binary, prefs_root, **kwargs)
         env_options = get_options(product)
 
         unexpected_total = 0
